@@ -1,18 +1,20 @@
 from collections import namedtuple
 from warnings import warn
+from typing import List, NamedTuple, Optional, Tuple, Union
 
 from json import loads
 
 from .author_search import AuthorSearch
 from .scopus_search import ScopusSearch
 from pybliometrics.scopus.superclasses import Retrieval
-from pybliometrics.scopus.utils import chained_get, get_content, get_link,\
-    listify, parse_affiliation, parse_date_created
+from pybliometrics.scopus.utils import chained_get, check_parameter_value,\
+    get_content, get_link, listify, make_int_if_possible, parse_affiliation,\
+    parse_date_created
 
 
 class AuthorRetrieval(Retrieval):
     @property
-    def affiliation_current(self):
+    def affiliation_current(self) -> Optional[List[NamedTuple]]:
         """A list of namedtuples representing the authors's current
         affiliation(s), in the form (id parent type relationship afdispname
         preferred_name parent_preferred_name country_code country address_part
@@ -21,11 +23,11 @@ class AuthorRetrieval(Retrieval):
         when it lookes correct in the web view.  In this case please request
         a correction.
         """
-        path = ["author-profile", "affiliation-current", "affiliation"]
-        return parse_affiliation(chained_get(self._json, path))
+        affs = chained_get(self._profile, ["affiliation-current", "affiliation"])
+        return parse_affiliation(affs)
 
     @property
-    def affiliation_history(self):
+    def affiliation_history(self) -> Optional[List[NamedTuple]]:
         """A list of namedtuples representing the authors's historical
         affiliation(s), in the form (id parent type relationship afdispname
         preferred_name parent_preferred_name country_code country address_part
@@ -37,80 +39,83 @@ class AuthorRetrieval(Retrieval):
         Note: Unlike on their website, Scopus doesn't provide the periods
         of affiliation.
         """
-        path = ["author-profile", "affiliation-history", "affiliation"]
-        return parse_affiliation(chained_get(self._json, path))
+        affs = chained_get(self._profile, ["affiliation-history", "affiliation"])
+        return parse_affiliation(affs)
 
     @property
-    def alias(self):
-        """Set of possible new Scopus Author Profile IDs in case the profile has been merged."""
+    def alias(self) -> Optional[List[str]]:
+        """List of possible new Scopus Author Profile IDs in case the profile
+        has been merged.
+        """
         return self._alias
-        
+
     @property
-    def citation_count(self):
+    def citation_count(self) -> int:
         """Total number of citing items."""
-        return self._json['coredata'].get('citation-count', '0')
+        return int(self._json['coredata']['citation-count'])
 
     @property
-    def cited_by_count(self):
+    def cited_by_count(self) -> int:
         """Total number of citing authors."""
-        return self._json['coredata'].get('cited-by-count', '0')
+        return int(self._json['coredata']['cited-by-count'])
 
     @property
-    def coauthor_count(self):
-        """Total number of coauthors."""
-        return self._json.get('coauthor-count', '0')
-
-    @property
-    def classificationgroup(self):
+    def classificationgroup(self) -> Optional[List[Tuple[int, int]]]:
         """List with (subject group ID, number of documents)-tuples."""
-        path = ['author-profile', 'classificationgroup', 'classifications',
-                'classification']
-        out = [(item['$'], item['@frequency']) for item in
-               listify(chained_get(self._json, path, []))]
+        path = ['classificationgroup', 'classifications', 'classification']
+        out = [(int(item['$']), int(item['@frequency'])) for item in
+               listify(chained_get(self._profile, path, []))]
         return out or None
 
     @property
-    def coauthor_link(self):
+    def coauthor_count(self) -> Optional[int]:
+        """Total number of coauthors."""
+        return make_int_if_possible(chained_get(self._json, ['coauthor-count']))
+
+    @property
+    def coauthor_link(self) -> Optional[str]:
         """URL to Scopus API search page for coauthors."""
         return get_link(self._json, 3)
 
     @property
-    def date_created(self):
+    def date_created(self) -> Optional[Tuple[int, int, int]]:
         """Date the Scopus record was created."""
-        return parse_date_created(self._json['author-profile'])
+        try:
+            return parse_date_created(self._profile)
+        except KeyError:
+            return None
 
     @property
-    def document_count(self):
+    def document_count(self) -> int:
         """Number of documents authored (excludes book chapters and notes)."""
-        return self._json['coredata'].get('document-count', '0')
+        return int(self._json['coredata']['document-count'])
 
     @property
-    def eid(self):
+    def eid(self) -> Optional[str]:
         """The EID of the author.  If it differs from the one provided,
         pybliometrics will throw a warning informing the user about
         author profile merges.
         """
-        return self._json['coredata']['eid']
+        return self._json['coredata'].get('eid')
 
     @property
-    def given_name(self):
+    def given_name(self) -> Optional[str]:
         """Author's preferred given name."""
-        path = ['author-profile', 'preferred-name', 'given-name']
-        return chained_get(self._json, path)
+        return chained_get(self._profile, ['preferred-name', 'given-name'])
 
     @property
-    def h_index(self):
+    def h_index(self) -> Optional[str]:
         """The author's h-index."""
-        return self._json.get('h-index', '0')
+        return make_int_if_possible(chained_get(self._json, ['h-index']))
 
     @property
-    def historical_identifier(self):
+    def historical_identifier(self) -> Optional[List[int]]:
         """Scopus IDs of previous profiles now compromising this profile."""
         hist = chained_get(self._json, ["coredata", 'historical-identifier'], [])
-        return [d['$'].split(":")[-1] for d in hist] or None
+        return [int(d['$'].split(":")[-1]) for d in hist] or None
 
     @property
-    def identifier(self):
+    def identifier(self) -> int:
         """The author's ID.  Might differ from the one provided."""
         ident = self._json['coredata']['dc:identifier'].split(":")[-1]
         if ident != self._id:
@@ -118,120 +123,130 @@ class AuthorRetrieval(Retrieval):
                    f"ID is {ident}.  Please update your records manually.  "\
                    "Files have been cached with the old ID."
             warn(text, UserWarning)
-        return ident
+        return int(ident)
 
     @property
-    def indexed_name(self):
+    def indexed_name(self) -> Optional[str]:
         """Author's name as indexed by Scopus."""
-        path = ['author-profile', 'preferred-name', 'indexed-name']
-        return chained_get(self._json, path)
+        return chained_get(self._profile, ['preferred-name', 'indexed-name'])
 
     @property
-    def initials(self):
+    def initials(self) -> Optional[str]:
         """Author's preferred initials."""
-        path = ['author-profile', 'preferred-name', 'initials']
-        return chained_get(self._json, path)
+        return chained_get(self._profile, ['preferred-name', 'initials'])
 
     @property
-    def name_variants(self):
+    def name_variants(self) -> Optional[List[NamedTuple]]:
         """List of named tuples containing variants of the author name with
         number of documents published with that variant.
         """
         fields = 'indexed_name initials surname given_name doc_count'
         variant = namedtuple('Variant', fields)
-        path = ['author-profile', 'name-variant']
         out = [variant(indexed_name=var['indexed-name'], surname=var['surname'],
                        doc_count=var.get('@doc-count'), initials=var['initials'],
                        given_name=var.get('given-name'))
-               for var in listify(chained_get(self._json, path, []))]
+               for var in listify(self._profile.get('name-variant', []))]
         return out or None
 
     @property
-    def orcid(self):
+    def orcid(self) -> Optional[str]:
         """The author's ORCID."""
         return self._json['coredata'].get('orcid')
 
     @property
-    def publication_range(self):
+    def publication_range(self) -> Optional[Tuple[int, int]]:
         """Tuple containing years of first and last publication."""
-        r = self._json['author-profile']['publication-range']
-        return (r['@start'], r['@end'])
-        return self._json['coredata'].get('orcid')
+        r = self._profile.get('publication-range')
+        try:
+            return int(r['@start']), int(r['@end'])
+        except TypeError:
+            return None
 
     @property
-    def scopus_author_link(self):
+    def scopus_author_link(self) -> Optional[str]:
         """Link to the Scopus web view of the author."""
         return get_link(self._json, 1)
 
     @property
-    def search_link(self):
+    def search_link(self) -> Optional[str]:
         """URL to the API page listing documents of the author."""
         return get_link(self._json, 2)
 
     @property
-    def self_link(self):
+    def self_link(self) -> Optional[str]:
         """Link to the author's API page."""
         return get_link(self._json, 0)
 
     @property
-    def status(self):
+    def status(self) -> Optional[str]:
         """The status of the author profile."""
-        return chained_get(self._json, ["author-profile", "status"])
+        return self._profile.get("status")
 
     @property
-    def subject_areas(self):
+    def subject_areas(self) -> Optional[List[NamedTuple]]:
         """List of named tuples of subject areas in the form
         (area, abbreviation, code) of author's publication.
         """
         path = ['subject-areas', 'subject-area']
         area = namedtuple('Subjectarea', 'area abbreviation code')
-        areas = [area(area=item['$'], code=item['@code'],
+        areas = [area(area=item['$'], code=int(item['@code']),
                       abbreviation=item['@abbrev'])
                  for item in chained_get(self._json, path, [])]
         return areas or None
 
     @property
-    def surname(self):
+    def surname(self) -> Optional[str]:
         """Author's preferred surname."""
-        path = ['author-profile', 'preferred-name', 'surname']
-        return chained_get(self._json, path)
+        return chained_get(self._profile, ['preferred-name', 'surname'])
 
     @property
-    def url(self):
+    def url(self) -> Optional[str]:
         """URL to the author's API page."""
         return self._json['coredata']['prism:url']
 
-    def __init__(self, author_id, refresh=False):
+    def __init__(self,
+                 author_id: Union[int, str],
+                 refresh: Union[bool, int] = False,
+                 view: str = "ENHANCED"
+                 ) -> None:
         """Interaction with the Author Retrieval API.
 
-        Parameters
-        ----------
-        author_id : str or int
-            The ID of the author to search for.  Optionally expressed
-            as an Elsevier EID (i.e., in the form 9-s2.0-nnnnnnnn).
+        :param author_id: The ID or the EID of the author.
+        :param refresh: Whether to refresh the cached file if it exists or not.
+                        If int is passed, cached file will be refreshed if the
+                        number of days since last modification exceeds that value.
+        :param view: The view of the file that should be downloaded.  Allowed
+                     values: METRICS, LIGHT, STANDARD, ENHANCED, where STANDARD
+                     includes all information of LIGHT view and ENHANCED
+                     includes all information of any view.  For details see
+                     https://dev.elsevier.com/sc_author_retrieval_views.html.
+                     Note: Neither the BASIC nor the DOCUMENTS view are active,
+                     although documented.
 
-        refresh : bool or int (optional, default=False)
-            Whether to refresh the cached file if it exists or not.  If int
-            is passed, cached file will be refreshed if the number of days
-            since last modification exceeds that value.
-
-        Examples
-        --------
-        See https://pybliometrics.readthedocs.io/en/stable/examples/AuthorRetrieval.html
+        Raises
+        ------
+        ValueError
+            If any of the parameters `refresh` or `view` is not
+            one of the allowed values.
 
         Notes
         -----
         The directory for cached results is `{path}/ENHANCED/{author_id}`,
-        where `path` is specified in `~/.scopus/config.ini` and `author_id`
+        where `path` is specified in your configuration file, and `author_id`
         is stripped of an eventually leading `'9-s2.0-'`.
         """
-        # Load json
-        view = "ENHANCED"  # In case Scopus adds different views in future
-        self._id = str(int(str(author_id).split('-')[-1]))
-        Retrieval.__init__(self, identifier=self._id, api='AuthorRetrieval',
-                           refresh=refresh, view=view)
-        self._json = self._json['author-retrieval-response']
         # Checks
+        allowed_views = ('METRICS', 'LIGHT', 'STANDARD', 'ENHANCED')
+        check_parameter_value(view, allowed_views, "view")
+
+        # Load json
+        self._id = str(author_id).split('-')[-1]
+        self._view = view
+        self._refresh = refresh
+        Retrieval.__init__(self, identifier=self._id, api='AuthorRetrieval')
+
+        # Parse json
+        self._json = self._json['author-retrieval-response']
         try:
             self._json = self._json[0]
         except KeyError:  # Incomplete forward
@@ -245,6 +260,7 @@ class AuthorRetrieval(Retrieval):
             warn(text, UserWarning)
         else:
             self._alias = None
+        self._profile = self._json.get("author-profile", {})
 
     def __str__(self):
         """Return a summary string."""
@@ -257,30 +273,32 @@ class AuthorRetrieval(Retrieval):
             f"{int(self.citation_count):,} document(s) as of {date}"
         return s
 
-    def get_coauthors(self):
+    def get_coauthors(self) -> Optional[List[NamedTuple]]:
         """Retrieves basic information about co-authors as a list of
         namedtuples in the form
         (surname, given_name, id, areas, affiliation_id, name, city, country),
         where areas is a list of subject area codes joined by "; ".
         Note: Method retrieves information via individual queries which will
-        not be cached.  The Scopus API does returns 160 coauthors at most.
+        not be cached.  The Scopus API returns 160 coauthors at most.
         """
         SIZE = 25
         # Get number of authors to search for
         url = self.coauthor_link
-        res = get_content(url=url)
+        if not url:
+            return None
+        res = get_content(url, api="AuthorSearch")
         data = loads(res.text)['search-results']
         N = int(data.get('opensearch:totalResults', 0))
         # Store information in namedtuples
         fields = 'surname given_name id areas affiliation_id name city country'
         coauth = namedtuple('Coauthor', fields)
         coauthors = []
-        # Iterate over search results in chunks of 25 results
+        # Iterate over search results in chunks of `SIZE` results
         count = SIZE
         start = 0
         while start < N:
-            params = {'start': start, 'count': count}
-            res = get_content(url=url, params=params, accept='json')
+            params = {'start': start, 'count': count, 'accept': 'json'}
+            res = get_content(url, api="AuthorSearch", params=params)
             data = loads(res.text)['search-results'].get('entry', [])
             # Extract information for each coauthor
             for entry in data:
@@ -291,7 +309,7 @@ class AuthorRetrieval(Retrieval):
                     areas = [entry['subject-area']['$']]
                 new = coauth(surname=entry['preferred-name']['surname'],
                     given_name=entry['preferred-name'].get('given-name'),
-                    id=entry['dc:identifier'].split(':')[-1],
+                    id=int(entry['dc:identifier'].split(':')[-1]),
                     areas='; '.join(areas), name=aff.get('affiliation-name'),
                     affiliation_id=aff.get('affiliation-id'),
                     city=aff.get('affiliation-city'),
@@ -300,22 +318,16 @@ class AuthorRetrieval(Retrieval):
             start += SIZE
         return coauthors or None
 
-    def get_documents(self, subtypes=None, **kwds):
+    def get_documents(self,
+                      subtypes: List[str] = None,
+                      *args: str, **kwds: str
+                      ) -> Optional[List[NamedTuple]]:
         """Return list of the author's publications using a ScopusSearch()
         query, where publications may fit specified set of document subtypes.
 
-        Parameters
-        ----------
-        subtypes : list of str (optional, default=None)
-            The type of documents that should be returned.
-
-        **kwds : dict-like
-            Parameters to be passed on to ScopusSearch().
-
-        Returns
-        -------
-        results : list of namedtuple
-            The same type of results returned from any ScopusSearch().
+        :param subtypes: The type of documents that should be returned.
+        :param args: Parameters to be passed on to ScopusSearch().
+        :param kwds: Parameters to be passed on to ScopusSearch().
         """
         s = ScopusSearch(f'AU-ID({self.identifier})', **kwds)
         if subtypes:
@@ -323,35 +335,36 @@ class AuthorRetrieval(Retrieval):
         else:
             return s.results
 
-    def get_document_eids(self, *args, **kwds):
+    def get_document_eids(self,
+                          *args: str, **kwds: str
+                          ) -> Optional[List[str]]:
         """Return list of EIDs of the author's publications using
         a ScopusSearch() query.
+
+        :param args: Parameters to be passed on to ScopusSearch().
+        :param kwds: Parameters to be passed on to ScopusSearch().
         """
         s = ScopusSearch(f'AU-ID({self.identifier})', *args, **kwds)
         return s.get_eids()
 
-    def estimate_uniqueness(self, query=None, *args, **kwds):
-        """Estimate how unqiue a profile is by get the number of
-        matches of an AuthorSearch for this person.
+    def estimate_uniqueness(self,
+                            query: str = None,
+                            *args: str,
+                            **kwds: str
+                            ) -> int:
+        """Return the number of Scopus author profiles similar to this profile
+        via calls with AuthorSearch().
 
-        Parameters
-        ----------
-        query : str (optional, default=None)
-            The query string to perform to search for authors.  If empty,
-            the query is of form "AUTHLAST() AND AUTHFIRST()" with the
-            corresponding information included.  Provided queries may include
-            "SUBJAREA()" OR "AF-ID() AND SUBJAREA()".  For details see
-            https://dev.elsevier.com/tips/AuthorSearchTips.htm.
-
-        args, kwds : key-value pairings
-            Parameters to be passed on to AuthorSearch().
-
-        Returns
-        -------
-        n : int
-            The number of matches of the query.
+        :param query: The query string to perform to search for authors.  If
+                      `None`, the query is of form "AUTHLAST() AND AUTHFIRST()"
+                      with the corresponding information included.  Provided
+                      queries may include "SUBJAREA()" OR "AF-ID() AND
+                      SUBJAREA()".  For details see
+                      https://dev.elsevier.com/tips/AuthorSearchTips.htm.
+        :param args: Parameters to be passed on to AuthorSearch().
+        :param kwds: Parameters to be passed on to AuthorSearch().
         """
         if not query:
             query = f"AUTHLAST({self.surname}) AND AUTHFIRST({self.given_name})"
-        s = AuthorSearch(query, **kwds)
+        s = AuthorSearch(query, *args, **kwds)
         return s.get_results_size()
