@@ -1,15 +1,16 @@
 from collections import OrderedDict
+from typing import Dict, List, Optional, Union
 
 from pybliometrics.scopus.superclasses import Search
-from pybliometrics.scopus.utils import make_search_summary
+from pybliometrics.scopus.utils import check_parameter_value, make_search_summary
 
 
 class SerialSearch(Search):
     @property
-    def results(self):
+    def results(self) -> Optional[List[Dict[str, str]]]:
         """A list of OrderedDicts representing results of serial search. The
         number of keys may vary from one search result to another depending
-        on the length of yearly data. Note: can be empty.
+        on the length of yearly data.
         """
         out = []
         search_results = self._json['serial-metadata-response'].get('entry', [])
@@ -46,26 +47,23 @@ class SerialSearch(Search):
                 out.append(obs)
         return out or None
 
-    def __init__(self, query, refresh=False, view='ENHANCED'):
+    def __init__(self,
+                 query: Dict,
+                 refresh: Union[bool, int] = False,
+                 view: str = 'ENHANCED'
+                 ) -> None:
         """Interaction with the Serial Title API.
 
-        Parameters
-        ----------
-        query: dict
-            Query parameters and corresponding fields. Allowed keys 'title',
-            'issn', 'pub', 'subj', 'subjCode', 'content', 'oa'.  For
-            examples on possible values, please refer to
-            https://dev.elsevier.com/documentation/SerialTitleAPI.wadl#d1e22.
-        
-        refresh : bool or int (optional, default=False)
-            Whether to refresh the cached file if it exists or not.  If int
-            is passed, cached file will be refreshed if the number of days
-            since last modification exceeds that value.
-
-        view : str (optional, default="ENHANCED")
-            The view of the file that should be downloaded.  Allowed values:
-            STANDARD, ENHANCED, CITESCORE.  For details see
-            https://dev.elsevier.com/guides/SerialTitleViews.htm.
+        :param query:  Query parameters and corresponding fields. Allowed keys
+                      'title', 'issn', 'pub', 'subj', 'subjCode', 'content',
+                      'oa'.  For examples on possible values, please refer to
+                      https://dev.elsevier.com/documentation/SerialTitleAPI.wadl#d1e22.
+        :param refresh: Whether to refresh the cached file if it exists or not.
+                        If int is passed, cached file will be refreshed if the
+                        number of days since last modification exceeds that value.
+        :param view: The view of the file that should be downloaded.  Allowed
+                     values: STANDARD, ENHANCED, CITESCORE.  For details see
+                     https://dev.elsevier.com/sc_serial_title_views.html.
 
         Raises
         ------
@@ -74,17 +72,13 @@ class SerialSearch(Search):
             non-subscribers the number of search results exceeds 5000.
 
         ValueError
-            If view parameter is not one of allowed ones or if query contains
-            invalid fields.
-
-        Examples
-        --------
-        See https://pybliometrics.readthedocs.io/en/stable/examples/SerialSearch.html.
+            If any of the parameters `refresh` or `view` is not
+            one of the allowed values.
 
         Notes
         -----
         The directory for cached results is `{path}/{view}/{fname}`,
-        where `path` is specified in `~/.scopus/config.ini` and fname is
+        where `path` is specified in your configuration file, and `fname` is
         the md5-hashed version of `query` dict turned into string in format
         of 'key=value' delimited by '&'.
         """
@@ -94,15 +88,13 @@ class SerialSearch(Search):
         invalid = [k for k in query.keys() if k not in allowed_query_keys]
         if invalid:
             raise ValueError(f'Query key(s) "{", ".join(invalid)}" invalid')
-        allowed_views = ('STANDARD', 'ENHANCED', 'CITESCORE')
-        if view not in allowed_views:
-            raise ValueError('view parameter must be one of ' +
-                             ', '.join(allowed_views))
+        check_parameter_value(view, ('STANDARD', 'ENHANCED', 'CITESCORE'), "view")
 
         # Query
-        self.query = str(query)
-        Search.__init__(self, query=query, api='SerialSearch',
-                        refresh=refresh, view=view)
+        self._query = str(query)
+        self._refresh = refresh
+        self._view = view
+        Search.__init__(self, query=query, api='SerialSearch')
         self._n = len(self._json['serial-metadata-response'].get('entry', []))
 
     def __str__(self):
@@ -113,35 +105,35 @@ class SerialSearch(Search):
 
 def _merge_subject_data(subject_area_data):
     """Auxiliary function to collect and concatenate subject area data into string.
-    
+
     Returns tuple of strings for subject area names, subject area codes and
     subject area abbreviations deliminated by ';'.
     """
-    codes = set([j.get('@code') for j in subject_area_data if j.get('@code')])
-    abbrevs = set([j.get('@abbrev')
-                   for j in subject_area_data
-                   if j.get('@abbrev')])
-    names = set([j.get('$')
-                 for j in subject_area_data
-                 if j.get('$')])
-    return (';'.join(codes), ';'.join(abbrevs), ';'.join(names))
+    codes = set([j.get('@code') for j in subject_area_data])
+    abbrevs = set([j.get('@abbrev') for j in subject_area_data])
+    names = set([j.get('$') for j in subject_area_data])
+    return (';'.join(filter(None, codes)),
+            ';'.join(filter(None, abbrevs)),
+            ';'.join(filter(None, names)))
 
 
 def _retrieve_links(link_data):
     """Auxiliary function to collect data on links.
-    
+
     Returns list of lists in the form of [linkname, link].
     """
     out = []
-    for l in link_data:
-        if l.get('@ref'):
-            out.append([l['@ref'], l.get('@href')])
+    for sl in link_data:
+        try:
+            out.append([sl['@ref'], sl.get('@href')])
+        except KeyError:
+            continue
     return out or None
 
 
 def _retrieve_yearly_data(yearly_data):
     """Auxiliary function to collect yearly data.
-    
+
     Returns list of lists in the form [mergedstatname, stat], where
     mergedstatname - dictionary key joined with associated period.
     """
@@ -149,35 +141,30 @@ def _retrieve_yearly_data(yearly_data):
     for t in yearly_data:
         for key in t:
             if key not in ('@year', '@_fa'):
-                out.append([key + '_' + str(t.get('@year')), t[key]])
+                out.append([f"{key}_{t['@year']}", t[key]])
     return out or None
 
 
 def _retrieve_cite_scores(cite_score_data):
     """Auxiliary function to collect citescore data.
-    
+
     Returns list of lists in the form [mergedstatname, stat], where
     mergedstatname - dictionary key joined with associated period.
     """
     out = []
-    if cite_score_data.get('citeScoreTracker'):
-        tracker_year = ('citeScoreTracker'
-                        + '_'
-                        + str(cite_score_data.get('citeScoreTrackerYear')))
-        tracker_val = cite_score_data['citeScoreTracker']
-        out.append([tracker_year, tracker_val])
-    if cite_score_data.get('citeScoreCurrentMetric'):
-        metric_year = ('citeScoreCurrentMetric'
-                       + '_'
-                       + str(cite_score_data.get('citeScoreCurrentMetricYear')))
-        metric_val = cite_score_data.get('citeScoreCurrentMetric')
-        out.append([metric_year, metric_val])
+    for key in ("citeScoreTracker", "citeScoreCurrentMetric"):
+        try:
+            year = f"{key}_{cite_score_data[key + 'Year']}"
+            val = cite_score_data[key]
+            out.append([year, val])
+        except KeyError:
+            pass
     return out or None
 
 
 def _retrieve_source_rankings(source_data):
     """Auxiliary function to collect SNIP and SJR data.
-    
+
     Returns list of lists in the form [mergedstatname, stat],
     where mergedstatname - dictionary key joined with associated period
     """
@@ -185,7 +172,5 @@ def _retrieve_source_rankings(source_data):
     for key in source_data:
         stats = source_data[key]
         for t in stats:
-            stat_name = str(key + '_' + t.get('@year'))
-            stat_val = t.get('$')
-            out.append([stat_name, stat_val])
+            out.append([f"{key}_['@year']", t['$']])
     return out or None
