@@ -63,12 +63,12 @@ def test_authkeywords():
 
 def test_authorgroup():
     fields = 'affiliation_id dptid organization city postalcode '\
-             'addresspart country auid indexed_name surname given_name'
+             'addresspart country auid orcid indexed_name surname given_name'
     auth = namedtuple('Author', fields)
     expected = [auth(affiliation_id=60027950, dptid=110785688,
         organization='Department of Chemical Engineering, Carnegie Mellon University',
         city='Pittsburgh', postalcode='15213', addresspart='5000 Forbes Avenue',
-        country='United States', auid=7004212771,
+        country='United States', auid=7004212771, orcid=None,
         indexed_name='Kitchin J.', surname='Kitchin', given_name='John R.')]
     assert_equal(ab1.authorgroup, expected)
     assert_equal(ab8.authorgroup, None)
